@@ -22,6 +22,11 @@
 import os
 import shutil
 
+try:
+    import json
+except ImportError:
+    import simplejson as json
+
 import logging
 log = logging.getLogger('e3.common.Collections')
 
@@ -32,6 +37,7 @@ class ExtensionDescriptor(object):
 
     def __init__(self):
         self.files = {}
+        self.metadata = {}
 
     def add_file(self, file_name, blob):
         self.files[file_name] = blob
@@ -44,7 +50,7 @@ class Collection(object):
         self.theme = theme
         self.github = Github("emesene")
         self._stop = False
-        self._blobs = None
+        self._tree = None
         self.progress = 0.0
 
     def save_files(self, element, label):
@@ -76,7 +82,7 @@ class Collection(object):
             try:
                 rq = self.github.get_raw(self.theme, element[label].files[path])
             except Exception, ex:
-                log.error(str(ex))
+                log.exception(str(ex))
                 self.remove(removal_path)
                 return
 
@@ -97,29 +103,33 @@ class Collection(object):
     def stop(self):
         self._stop = True
 
-    def set_blobs(self, result):
-        self._blobs = result
+    def set_tree(self, result):
+        self._tree = result
 
     def plugin_name_from_file(self, file_name):
         pass
 
     def fetch(self):
         self._stop = False
-        self._blobs = None
+        self._tree = None
         self.progress = 0.0
 
-        AsyncAction(self.set_blobs, self.github.fetch_blob ,self.theme)
+        AsyncAction(self.set_tree, self.github.fetch_tree, self.theme)
 
-        while self._blobs is None:
+        while self._tree is None:
             if self._stop:
                 return
 
         self.progress = 0.5
-        j = self._blobs
 
-        for i, k in enumerate(j["blobs"]):
+        for i, item in enumerate(self._tree['tree']):
 
-            (type, name) = self.plugin_name_from_file(k)
+            if item.get('type') != 'blob':
+                continue
+
+            file_name = item.get('path')
+
+            (type, name) = self.plugin_name_from_file(file_name)
 
             if type is None:
                 continue
@@ -134,10 +144,33 @@ class Collection(object):
             except KeyError:
                 pl = extype[name] = ExtensionDescriptor()
 
-            pl.add_file(k, j["blobs"][k])
-            self.progress = i / float(len(j["blobs"]) * 2) + 0.5
+            pl.add_file(file_name, item.get('sha'))
+            self.progress = i / float(len(self._tree['tree']) * 2) + 0.5
         self.progress = 1.0
 
+    def has_item(self, type_, name):
+        current_ext = self.extensions_descs.get(type_, {}).get(name)
+        if not current_ext:
+            return False
+        return True
+
+    def fetch_metadata(self, type_, name):
+        '''fetch metadata if available'''
+        current_ext = self.extensions_descs.get(type_, {}).get(name)
+        if not current_ext:
+            return None
+
+        for path in current_ext.files.keys():
+            if os.path.basename(path) == 'meta.json':
+                try:
+                    rq = self.github.get_raw(self.theme, current_ext.files[path])
+                except Exception, ex:
+                    log.exception(str(ex))
+                    return None
+                current_ext.metadata = json.loads(rq)
+                return current_ext.metadata
+        return None
+
 class PluginsCollection(Collection):
 
     def plugin_name_from_file(self, file_name):
@@ -160,4 +193,3 @@ class ThemesCollection(Collection):
             return path.split("/")
         else:
             return (None, None)
-
