@@ -41,6 +41,8 @@ class Notification():
         self.session.config.get_or_set('b_notify_contact_online', True)
         self.session.config.get_or_set('b_notify_contact_offline', True)
         self.session.config.get_or_set('b_notify_receive_message', True)
+        self.session.config.get_or_set('b_notify_typing', False)
+        self.session.config.get_or_set('b_notify_when_focussed', False)
         self.session.config.get_or_set('b_notify_only_when_available', True)
 
         self.notifier = extension.get_default('notificationGUI')
@@ -50,6 +52,8 @@ class Notification():
         if self.session:
             self.session.signals.conv_message.subscribe(
                 self._on_message)
+            self.session.signals.user_typing.subscribe(
+                self._on_user_typing)
             self.session.signals.contact_attr_changed.subscribe(
                 self._on_contact_attr_changed)
             self.session.signals.mail_received.subscribe(
@@ -68,6 +72,8 @@ class Notification():
         if self.session:
             self.session.signals.conv_message.unsubscribe(
                 self._on_message)
+            self.session.signals.user_typing.unsubscribe(
+                self._on_user_typing)
             self.session.signals.contact_attr_changed.unsubscribe(
                 self._on_contact_attr_changed)
             self.session.signals.mail_received.unsubscribe(
@@ -97,6 +103,12 @@ class Notification():
         contact = self.session.contacts.get(arg1.sender.account)
         self._notify(contact, contact.nick, _("File transfer invitation"), arg1.sender.account)
 
+    def _on_user_typing(self, cid, account, *args):
+        ''' called when a user is typing '''
+        if self.session.config.b_notify_typing:
+            contact = self.session.contacts.get(account)
+            self._notify(contact, contact.nick, _("is typing a message"), account)
+
     def _on_mail_received(self, message):
         ''' called when a new mail is received '''
         uri = self.picture_factory('notification-message-email', 'mail-received')
@@ -127,11 +139,11 @@ class Notification():
         """
         conversation = self.has_similar_conversation(cid, account)
         contact = self.session.contacts.get(account)
-        
+
         text = None
         check = False
         if conversation:
-            check = conversation.message_waiting
+            check = conversation.message_waiting or self.session.config.b_notify_when_focussed
 
         if self.session.config.b_notify_receive_message and check:
             if msgobj.type == Message.TYPE_NUDGE:
@@ -198,10 +210,10 @@ class Notification():
                 uri = "file://" + contact.picture
             else:
                 uri = 'notification-message-im'
-            
+
             uri = self.picture_factory(uri, 'message-im')
-            
+
             if text is not None:
-                self.notifier(title, text, uri, 'message-im', None, tooltip)
+                self.notifier(title if title else '', text, uri, 'message-im', None, tooltip)
         if sound is not None:
             self.sound_player.play(sound)
