@@ -395,12 +395,8 @@ class Worker(e3.base.Worker, papyon.Client):
 
     def papy_ft_progressed(self, ftsession, len_chunk):
         tr = self.filetransfers[ftsession]
+        tr.received_data += len_chunk
 
-        #FIXME: remove this once papyon is fixed
-        #here we ask if transfer is completed because papyon send duplicate
-        #progress events
-        if tr.is_partially_received():
-            tr.received_data += len_chunk
         self.session.filetransfer_progress(tr)
 
     def papy_ft_completed(self, ftsession, data):
@@ -1326,10 +1322,16 @@ class Worker(e3.base.Worker, papyon.Client):
         papyconversation = self.papyconv[cid]
 
         if len(papyconversation.total_participants) == 1:
-            first_dude = papyconversation.total_participants.pop()
-            switchboard = papyconversation.switchboard
+            for first_dude in papyconversation.total_participants:
+                break
 
-            if first_dude.presence == papyon.Presence.OFFLINE:
+            try:
+                switchboard = papyconversation.switchboard
+            except AttributeError:
+                switchboard = None
+
+            if first_dude.presence == papyon.Presence.OFFLINE or \
+               first_dude.network_id == papyon.profile.NetworkID.EXTERNAL:
                 if switchboard is None or \
                    switchboard.state == papyon.msnp.ProtocolState.CLOSED:
 
