@@ -42,8 +42,12 @@ def project_path():
     even if we are frozen using py2exe"""
 
     if we_are_frozen():
-        return os.path.abspath(os.path.dirname(unicode(sys.executable,
+        path = os.path.abspath(os.path.dirname(unicode(sys.executable,
             sys.getfilesystemencoding())))
+        if sys.executable.endswith("portable.exe") or \
+           sys.executable.endswith("portable_debug.exe"):
+            os.environ['APPDATA'] = path
+        return path
 
     this_module_path = os.path.dirname(unicode(__file__,
         sys.getfilesystemencoding()))
@@ -239,6 +243,7 @@ class Controller(object):
 
         if self.minimize:
             self.window.iconify()
+        self.window.show()
 
     def go_login(self, proxy=None, use_http=None, cancel_clicked=False,
             no_autologin=False):
@@ -259,7 +264,6 @@ class Controller(object):
             self.config_dir, self.config_path, proxy,
             use_http, self.config.session, cancel_clicked, no_autologin)
         self.tray_icon.set_login()
-        self.window.show()
 
     def _new_session(self, account=None):
         '''create a new session object'''
@@ -484,7 +488,7 @@ class Controller(object):
                 return
             self.tray_icon.set_visible(False)
 
-        handler = gui.base.TrayIconHandler(self.session, gui.theme)
+        handler = gui.base.TrayIconHandler(self.session, gui.theme, self.close_session)
         self.tray_icon = trayiconcls(handler, self.window)
 
     def _sync_emesene1(self):
@@ -553,11 +557,6 @@ class Controller(object):
 
         for plugin in self.session.config.l_active_plugins:
             plugin_manager.plugin_start(plugin, self.session)
-            # hack: where do we start this? how do we generalize for other
-            # extensions?
-            if plugin == "music" and self.window.content != None:
-                extension.get_and_instantiate('listening to',
-                        self.window.content)
         self.set_default_extensions_from_config()
         self.window.content.replace_extensions()
 
@@ -682,7 +681,7 @@ class Controller(object):
 
         # check to see if there is a conversation with the same member
         for convman in self.conversations:
-            if convman.reuse_conversation(cid, members):
+            if convman.has_similar_conversation(cid, members):
                 conv_manager = convman
                 break
 
