@@ -104,6 +104,11 @@ class Conversation(object):
         self.session.signals.call_invitation.subscribe(
                 self.on_call_invitation)
 
+        self.session.signals.contact_block_succeed.subscribe(
+                self.on_contact_block_succeed)
+        self.session.signals.contact_unblock_succeed.subscribe(
+                self.on_contact_unblock_succeed)
+
     def unsubscribe_signals(self):
         ''' unsubscribes current session's signals '''
         self.session.config.unsubscribe(self._on_avatarsize_changed,
@@ -139,6 +144,11 @@ class Conversation(object):
         self.session.signals.call_invitation.unsubscribe(
                 self.on_call_invitation)
 
+        self.session.signals.contact_block_succeed.unsubscribe(
+                self.on_contact_block_succeed)
+        self.session.signals.contact_unblock_succeed.unsubscribe(
+                self.on_contact_unblock_succeed)
+
     def _get_style(self):
         '''return the value of style'''
         return self._style
@@ -238,6 +248,14 @@ class Conversation(object):
         else:
             self.session.block(account)
 
+    def on_contact_block_succeed(self, account):
+        if account == self.members[0]:
+            self.set_sensitive(False, False)
+
+    def on_contact_unblock_succeed(self, account):
+        if account == self.members[0]:
+            self.set_sensitive(True)
+
     def on_emote(self, emote):
         '''called when a emote is selected on the emote window'''
         self.input.append(emote)
@@ -285,7 +303,7 @@ class Conversation(object):
         """
         raise NotImplementedError("Method not implemented")
 
-    def set_sensitive(self, is_sensitive):
+    def set_sensitive(self, is_sensitive, toolbar=True):
         """
         used to make the conversation insensitive while the conversation
         is still open while the user is disconnected and to set it back to
@@ -348,13 +366,8 @@ class Conversation(object):
 
     is_group_chat = property(fget=_get_group_chat)
 
-    def _on_send_message(self, text):
-        '''method called when the user press enter on the input text'''
-        cedict = self.emcache.parse()
-        custom_emoticons = gui.base.MarkupParser.get_custom_emotes(text, cedict)
-
-        self.session.send_message(self.cid, text, self.cstyle, cedict, custom_emoticons)
-        message = e3.Message(e3.Message.TYPE_MESSAGE, text, None, self.cstyle)
+    def output_message(self, message, cedict):
+        '''display current outgoing message into OutputText'''
 
         msg = self.conv_status.pre_process_message(self.session.contacts.me,
             message, False, cedict, self.emcache.path, message.timestamp,
@@ -364,10 +377,31 @@ class Conversation(object):
 
         self.conv_status.post_process_message(msg)
 
+    def _on_send_message(self, text):
+        '''method called when the user press enter on the input text'''
+        cedict = self.emcache.parse()
+        custom_emoticons = gui.base.MarkupParser.get_custom_emotes(text, cedict)
+
+        self.session.send_message(self.cid, text, self.cstyle, cedict, custom_emoticons)
+
+        message = e3.Message(e3.Message.TYPE_MESSAGE, text, None, self.cstyle)
+        self.output_message(message, cedict)
+
         self.messages.push(text)
         self.play_send()
         self.conv_status.update_status()
 
+    def input_message(self, message, contact, cedict, cepath):
+        '''display current ingoing message into OutputText'''
+
+        msg = self.conv_status.pre_process_message(contact,
+                message, True, cedict, cepath,
+                message.timestamp, message.type, message.style)
+
+        self.output.receive_message(self.formatter, msg)
+
+        self.conv_status.post_process_message(msg)
+
     def on_receive_message(self, message, account, received_custom_emoticons):
         '''method called when a message arrives to the conversation'''
         contact = self.session.contacts.get(account)
@@ -381,13 +415,7 @@ class Conversation(object):
 
             user_emcache = self.caches.get_emoticon_cache(account)
 
-            msg = self.conv_status.pre_process_message(contact,
-                message, True, received_custom_emoticons, user_emcache.path,
-                message.timestamp, message.type, message.style)
-
-            self.output.receive_message(self.formatter, msg)
-
-            self.conv_status.post_process_message(msg)
+            self.input_message(message, contact, received_custom_emoticons, user_emcache.path)
 
             self.play_type()
 
@@ -399,6 +427,13 @@ class Conversation(object):
             self.conv_status.post_process_message(msg)
 
             self.play_nudge()
+
+        elif message.type == e3.Message.TYPE_INFO:
+            msg = gui.Message.from_information(contact, message)
+
+            self.output.information(self.formatter, msg)
+            self.conv_status.post_process_message(msg)
+
         self.conv_status.update_status()
 
     def on_send_message_failed(self, errorCode):
@@ -521,7 +556,11 @@ class Conversation(object):
         contact = self.session.contacts.get(account)
 
         if contact:
-            message = MarkupParser.escape(contact.message)
+            if contact.media == '':
+                message = MarkupParser.escape(contact.message)
+            else:
+                message = MarkupParser.escape(contact.media)
+
             nick = MarkupParser.escape(contact.display_name)
         else:
             message = ''
