@@ -17,6 +17,7 @@
 #    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 import e3
+import extension
 
 import logging
 log = logging.getLogger('gui.base.ConversationManager')
@@ -39,9 +40,16 @@ class ConversationManager(object):
         if self.session.conversations is None or conversation_tabs:
             self.session.conversations = {}
 
+        self.aftconv = None
+        AfterConversation = extension.get_default('after_new_conversation')
+        if AfterConversation is not None:
+            self.aftconv = AfterConversation(self.session)
+
     def subscribe_signals(self):
         self.session.signals.conv_message.subscribe(
             self._on_message)
+        self.session.signals.info_message.subscribe(
+            self._on_message)
         self.session.signals.user_typing.subscribe(
             self._on_user_typing)
         self.session.signals.conv_contact_joined.subscribe(
@@ -62,6 +70,8 @@ class ConversationManager(object):
     def unsubscribe_signals(self):
         self.session.signals.conv_message.unsubscribe(
             self._on_message)
+        self.session.signals.info_message.unsubscribe(
+            self._on_message)
         self.session.signals.user_typing.unsubscribe(
             self._on_user_typing)
         self.session.signals.conv_contact_joined.unsubscribe(
@@ -95,8 +105,8 @@ class ConversationManager(object):
             conversation = self.new_conversation(cid, [account])
 
         if conversation is not None:
-            conversation.on_receive_message(message, account, cedict)
             self.set_message_waiting(conversation, True)
+            conversation.on_receive_message(message, account, cedict)
 
     def _on_user_typing(self, cid, account, *args):
         """
@@ -180,15 +190,16 @@ class ConversationManager(object):
         if cid in self.conversations:
             return self.conversations[cid]
 
-        elif members is not None:
+        if members is not None:
             for conversation in self.conversations.itervalues():
                 if conversation.members == members:
                     return conversation
 
-        else:
-            for conversation in self.conversations.itervalues():
-                if conversation.icid == cid:
-                    return conversation
+        for conversation in self.conversations.itervalues():
+            if conversation.icid == cid:
+                return conversation
+
+        return None
 
     def reuse_conversation(self, cid, members):
         '''
@@ -202,20 +213,20 @@ class ConversationManager(object):
         '''
         conversation = self.has_similar_conversation(cid, members)
 
-        if conversation:
-            old_cid = conversation.cid
+        if conversation is None:
+            return None
 
-            if old_cid in self.conversations:
-                del self.conversations[old_cid]
-            if old_cid in self.session.conversations:
-                del self.session.conversations[old_cid]
+        old_cid = conversation.cid
 
-            conversation.cid = cid
-            self.conversations[cid] = conversation
-            self.session.conversations[cid] = conversation
-            return conversation
+        if old_cid in self.conversations:
+            del self.conversations[old_cid]
+        if old_cid in self.session.conversations:
+            del self.session.conversations[old_cid]
 
-        return None
+        conversation.cid = cid
+        self.conversations[cid] = conversation
+        self.session.conversations[cid] = conversation
+        return conversation
 
     def new_conversation(self, cid, members=None):
         '''create a new conversation widget and append it to the tabs,
@@ -236,9 +247,10 @@ class ConversationManager(object):
 
     def after_new_conversation(self, conversation):
         '''
-         Override what to do after create a conversation
+         What to do after create a conversation
         '''
-        pass
+        if self.aftconv is not None:
+            self.aftconv.run(conversation)
 
     def renew_session(self, session):
         '''reopen all conversations when the user reconnects'''
