@@ -17,7 +17,6 @@
 #    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 import os
-import sys
 import re
 import time
 import urllib
@@ -45,8 +44,8 @@ EMESENE_LICENSE = '''    emesene is free software; you can redistribute it and/o
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 '''
 
-EMESENE_VERSION = "2.11.11"
-EMESENE_LAST_STABLE = "2.11.11"
+EMESENE_VERSION = "2.12.1"
+EMESENE_LAST_STABLE = "2.12.1"
 EMESENE_WEBSITE = "http://www.emesene.org"
 EMESENE_AUTHORS = "marianoguerra & c10ud"
 EMESENE_CONTRIBUTORS = [ # TODO: Load this from CONTRIBUTORS
@@ -80,9 +79,10 @@ class FileHandler(object):
     menu items
     '''
 
-    def __init__(self, session):
+    def __init__(self, session, on_quit=None):
         '''constructor'''
         self.session = session
+        self.on_quit = on_quit
 
     def on_status_selected(self, stat):
         '''called when a status is selected on the status menu'''
@@ -94,7 +94,10 @@ class FileHandler(object):
 
     def on_quit_selected(self):
         '''called when a status is selected on the status menu'''
-        self.session.close(True)
+        if self.on_quit:
+            self.on_quit()
+        else:
+            self.session.close(True)
 
 class ActionsHandler(object):
     '''this handler contains all the handlers needed to handle the actions
@@ -576,14 +579,14 @@ class TrayIconHandler(FileHandler):
     this handler contains all the methods to handle a tray icon
     """
 
-    def __init__(self, session, theme, on_disconnect=None, on_quit=None):
+    def __init__(self, session, theme, on_quit=None):
         """
         constructor
 
         session -- a e3.Session implementation
         theme -- a gui.Theme object
         """
-        FileHandler.__init__(self, session)
+        FileHandler.__init__(self, session, on_quit)
         self.theme = theme
         
     def on_hide_show_mainwindow(self, main_window=None):
