@@ -389,6 +389,8 @@ class ChatWidget(gtk.VBox):
         if not results:
             return
 
+        self.conv_status.clear()
+
         for stat, timestamp, msg_text, nick, account in results:
             is_me = self.session.contacts.me.account == account
             if is_me:
@@ -400,7 +402,7 @@ class ChatWidget(gtk.VBox):
                 contact = e3.Contact(account, nick=nick)
 
             datetimestamp = datetime.datetime.utcfromtimestamp(timestamp)
-            message = e3.Message(e3.Message.TYPE_MESSAGE, msg_text,
+            message = e3.Message(e3.Message.TYPE_OLDMSG, msg_text,
                         account, timestamp=datetimestamp)
 
             if is_me:
@@ -436,9 +438,8 @@ class ChatWidget(gtk.VBox):
             color = e3.Color.from_hex(color)
         except ValueError:
             color = self.session.config.font_color = '#000000'
-            color = e3.Color.from_hex(font_color)
+            color = e3.Color.from_hex(color)
 
         cstyle = e3.Style(color = color)
 
         return cstyle
-
