@@ -62,6 +62,11 @@ class Conversation(gtk.VBox, gui.Conversation):
         CallWidget = extension.get_default('call widget')
         dialog = extension.get_default('dialog')
 
+        self.below_conversation = None
+        BelowConversation = extension.get_default('below conversation')
+        if BelowConversation is not None:
+            self.below_conversation = BelowConversation(self, session)
+
         self.header = Header(session, members)
         toolbar_handler = gui.base.ConversationToolbarHandler(self.session,
             dialog, gui.theme, self)
@@ -104,6 +109,8 @@ class Conversation(gtk.VBox, gui.Conversation):
         self.pack_start(self.header, False)
         self.pack_start(self.hbox, True, True)
         self.pack_start(self.transfers_bar, False)
+        if self.below_conversation is not None:
+            self.pack_start(self.below_conversation, False)
 
         if len(self.members) == 0:
             self.header.information = ('connecting', 'creating conversation')
@@ -115,6 +122,7 @@ class Conversation(gtk.VBox, gui.Conversation):
                 his_picture = contact.picture or utils.path_to_url(os.path.abspath(gui.theme.image_theme.user))
                 nick = contact.nick
                 display_name = contact.display_name
+                self.set_sensitive(not contact.blocked, False)
             else:
                 his_picture = utils.path_to_url(os.path.abspath(gui.theme.image_theme.user))
                 nick = ""
@@ -307,15 +315,16 @@ class Conversation(gtk.VBox, gui.Conversation):
         self.info.update_group(self.members)
         self.update_tab()
 
-    def set_sensitive(self, is_sensitive):
+    def set_sensitive(self, is_sensitive, toolbar=True):
         """
         used to make the conversation insensitive while the conversation
         is still open while the user is disconnected and to set it back to
         sensitive when the user is reconnected
         """
         self.input.set_sensitive(is_sensitive)
-        self.toolbar.set_sensitive(is_sensitive)
         self.info.set_sensitive(is_sensitive)
+        if toolbar:
+            self.toolbar.set_sensitive(is_sensitive)
 
     def set_image_visible(self, is_visible):
         """
@@ -344,6 +353,22 @@ class Conversation(gtk.VBox, gui.Conversation):
     def get_preview(self, completepath):
         return utils.makePreview(completepath)
 
+    def _on_block_user_accept(self, accept, account):
+        if accept == stock.YES:
+            self.session.block(account)
+
+    def on_block_user(self):
+        '''blocks the first user of the conversation'''
+        account = self.members[0]
+        contact = self.session.contacts.contacts[account]
+
+        if contact.blocked:
+            self.session.unblock(account)
+        else:
+            dialog = extension.get_default('dialog')
+            dialog.yes_no(_("Are you sure you want to block this contact?"),
+                          self._on_block_user_accept, account)
+
     def on_user_typing(self, account):
         """
         inform that the other user has started typing
@@ -382,6 +407,9 @@ class Conversation(gtk.VBox, gui.Conversation):
         ''' called when contacts change their attributes'''
         if account in self.members and what in ('status', 'nick'):
             self.update_tab()
+        else:
+            if what == 'media':
+                self.update_data()
 
     def on_filetransfer_invitation(self, transfer, cid):
         ''' called when a new file transfer is issued '''
@@ -409,7 +437,7 @@ class Conversation(gtk.VBox, gui.Conversation):
     def on_filetransfer_rejected(self, transfer):
         ''' called when a file transfer is rejected '''
         if transfer in self.transfers_bar.transfers:
-            self.transfers_bar.update(transfer)
+            self.transfers_bar.canceled(transfer)
 
         if transfer.contact.account == self.members[0]:
             contact = self._member_to_contact(self.members[0])
@@ -500,4 +528,3 @@ class Conversation(gtk.VBox, gui.Conversation):
         elif path.startswith('file:'): # xffm
             path = path[5:] # 5 is len('file:')
         return path
-
