@@ -20,7 +20,6 @@ import gtk
 import base64
 import gobject
 import sys
-from shutil import rmtree
 
 import e3
 import gui
@@ -32,7 +31,7 @@ import stock
 import logging
 log = logging.getLogger('gtkui.Login')
 
-class LoginBase(gtk.Alignment):
+class LoginBaseUI(gtk.Alignment):
     ''' base widget that holds the visual stuff '''
     def __init__(self, callback, args=None):
         gtk.Alignment.__init__(self, xalign=0.5, yalign=0.5, xscale=0.0,
@@ -245,7 +244,7 @@ class LoginBase(gtk.Alignment):
         '''
         return
 
-class Login(LoginBase):
+class Login(LoginBaseUI, gui.LoginBase):
     '''
     widget that represents the login window
     '''
@@ -254,51 +253,14 @@ class Login(LoginBase):
                 use_http=None, session_id=None, cancel_clicked=False,
                 no_autologin=False):
 
-        LoginBase.__init__(self, callback)
+        LoginBaseUI.__init__(self, callback)
+        gui.LoginBase.__init__(self, callback, on_preferences_changed,
+                                config, config_dir, config_path,
+                                proxy, use_http, session_id, no_autologin)
 
-        self.config = config
-        self.config_dir = config_dir
-        self.config_path = config_path
-        self.callback = callback
         self.cancel_clicked = cancel_clicked
-        self.on_preferences_changed = on_preferences_changed
-        self.no_autologin = no_autologin
-        # the id of the default extension that handles the session
-        # used to select the default session on the preference dialog
-        self.use_http = use_http
-        self.session_id = session_id
 
         account = self.config.get_or_set('last_logged_account', '')
-        self.config.get_or_set('service', 'msn')
-        self.remembers = self.config.get_or_set('d_remembers', {})
-        self.config.get_or_set('d_user_service', {})
-        self.status = self.config.get_or_set('d_status', {})
-
-        #convert old configs to the new format
-        if len(account.split('|')) == 1:
-            config_keys = self.config.d_remembers.keys()
-            for _account in config_keys:
-                if len(_account.split('|')) != 1:
-                    continue
-                account_and_service = \
-                    _account + '|' + \
-                    self.config.d_user_service.get(_account, 'msn')
-                if _account == account:
-                    self.config.last_logged_account = account_and_service
-                    account = account_and_service
-                self.config.d_remembers[account_and_service] = \
-                    self.config.d_remembers.get(_account)
-                self.config.d_remembers.pop(_account, None)
-                self.config.d_status[account_and_service] = \
-                    self.config.d_status.get(_account)
-                self.config.d_status.pop(_account, None)
-                _value = self.config.d_accounts.get(_account)
-                if _value:
-                    self.config.d_accounts[account_and_service] = _value
-                self.config.d_accounts.pop(_account, None)
-            self.remembers = self.config.d_remembers
-            self.status = self.config.d_status
-        self.accounts = self.config.d_accounts
 
         self.b_connect.connect('clicked', self._on_connect_clicked)
 
@@ -306,34 +268,7 @@ class Login(LoginBase):
         self.new_combo_session()
         self._reload_account_list()
 
-        if proxy is None:
-            self.proxy = e3.Proxy()
-        else:
-            self.proxy = proxy
-
-        self.services = {}
-
-        if session_id is not None:
-            for ext_id, ext in extension.get_extensions('session').iteritems():
-                for service_name, service_data in ext.SERVICES.iteritems():
-                    self.services[service_name] = service_data
-
-                if session_id == ext_id and self.config.service in ext.SERVICES:
-                    self.server_host = ext.SERVICES[self.config.service]['host']
-                    self.server_port = ext.SERVICES[self.config.service]['port']
-                    break
-            else:
-                self.config.service = 'msn'
-                self.server_host = 'messenger.hotmail.com'
-                self.server_port = '1863'
-        else:
-            self.config.service = 'msn'
-            self.server_host = 'messenger.hotmail.com'
-            self.server_port = '1863'
-
-        avatar_path = self.config_dir.join(
-                        self.server_host, account.rpartition('|')[0],
-                        'avatars', 'last')
+        avatar_path = self.current_avatar_path(account.rpartition('|')[0])
         self.avatar.set_from_file(avatar_path)
 
         self.nicebar.hide()
@@ -357,7 +292,7 @@ class Login(LoginBase):
 
     def _on_session_changed(self, session_combo):
         service = self._get_active_service()
-        session_id, ext = self.session_name_to_ext[service]
+        session_id, ext = self.service2id[service]
         self._on_new_preferences(
             self.use_http, self.proxy.use_proxy, self.proxy.host,
             self.proxy.port, self.proxy.use_auth, self.proxy.user,
@@ -370,7 +305,6 @@ class Login(LoginBase):
         count = 0
         session_found = False
 
-        self.session_name_to_ext = {}
         self.session_name_to_index = {}
 
         if account in self.accounts:
@@ -395,7 +329,6 @@ class Login(LoginBase):
                     image = None
 
                 self.session_combo.get_model().append([image, service_name])
-                self.session_name_to_ext[service_name] = (ext_id, ext)
                 self.session_name_to_index[service_name] = count
                 count += 1
 
@@ -413,7 +346,7 @@ class Login(LoginBase):
         account = self.config.get_or_set('last_logged_account', '')
 
         if account != '' and int(self.config.d_remembers.get(account, 0)) == 3:
-            password = base64.b64decode(self.config.d_accounts[account])
+            password = self.decode_password(account)
 
             self.cmb_account.get_children()[0].set_text(account.rpartition('|')[0])
             self.txt_password.set_text(password)
@@ -438,41 +371,12 @@ class Login(LoginBase):
             self.show_error(_('user or password fields are empty'))
             return
 
-        self._config_account(account, remember_account, remember_password,
-                             auto_login)
+        self.config_account(account, self._get_active_service(), remember_account,
+                            remember_password, auto_login)
 
         self.callback(account, self.session_id, self.proxy, self.use_http,
                 self.server_host, self.server_port)
 
-    def _config_account(self, account, remember_account, remember_password,
-                         auto_login):
-        '''
-        modify the config for the current account before login
-        '''
-
-        account_and_session = account.account + '|' + self._get_active_service()
-
-        if auto_login or remember_account or remember_password:
-            self.status[account_and_session] = account.status
-            self.config.last_logged_account = account_and_session
-
-        if auto_login:#+1 account,+1 password,+1 autologin =  3
-            self.accounts[account_and_session] = base64.b64encode(account.password)
-            self.remembers[account_and_session] = 3
-
-        elif remember_password:#+1 account,+1 password = 2
-            self.accounts[account_and_session] = base64.b64encode(account.password)
-            self.remembers[account_and_session] = 2
-
-        elif remember_account:#+1 account = 1
-            self.accounts[account_and_session] = ''
-            self.remembers[account_and_session] = 1
-
-        else:#means i have logged with nothing checked
-            self.config.last_logged_account = ''
-
-        self.config.save(self.config_path)
-
     def _on_account_changed(self, entry):
         '''
         called when the content of the account entry changes
@@ -514,13 +418,7 @@ class Login(LoginBase):
         else:
             service = self._get_active_service()
 
-        if service in self.services:
-            service_data = self.services[service]
-            self.server_host = service_data['host']
-            self.server_port = service_data['port']
-            self.config.service = service
-            session_id, ext = self.session_name_to_ext[service]
-            self.session_id = session_id
+        self.update_service(service)
 
         if account + '|' + service in self.accounts:
             account_and_service = account + '|' + service
@@ -530,17 +428,16 @@ class Login(LoginBase):
             self.btn_status.set_status(int(self.status[account_and_service]))
             self.config.d_user_service[account] = service
 
-            passw = self.accounts[account_and_service]
-            avatar_path = self.config_dir.join(self.server_host, account,
-                                               'avatars', 'last')
+            passw = self.decode_password(account_and_service)
+            avatar_path = self.current_avatar_path(account)
             self.avatar.set_from_file(avatar_path)
 
             if attr == 3:#autologin,password,account checked
-                self.txt_password.set_text(base64.b64decode(passw))
+                self.txt_password.set_text(passw)
                 self.txt_password.set_sensitive(False)
                 self.auto_login.set_active(True)
             elif attr == 2:#password,account checked
-                self.txt_password.set_text(base64.b64decode(passw))
+                self.txt_password.set_text(passw)
                 self.txt_password.set_sensitive(False)
                 self.remember_password.set_active(True)
             elif attr == 1:#only account checked
@@ -633,26 +530,10 @@ class Login(LoginBase):
         '''
         def _yes_no_cb(response):
             '''callback from the confirmation dialog'''
-            account = self.cmb_account.get_active_text()
-            account_and_service =  account + '|' + self._get_active_service()
             if response == stock.YES:
-                try: # Delete user's folder
-                    rmtree(self.config_dir.join(self.server_host, account))
-                except:
-                    self.show_error(_('Error while deleting user'))
-
-                if account_and_service in self.accounts:
-                    del self.accounts[account_and_service]
-                if account_and_service in self.remembers:
-                    del self.remembers[account_and_service]
-                if account_and_service in self.status:
-                    del self.status[account_and_service]
-                if account in self.config.d_user_service:
-                    del self.config.d_user_service[account]
-                if account_and_service == self.config.last_logged_account:
-                    self.config.last_logged_account = ''
-
-                self.config.save(self.config_path)
+                account = self.cmb_account.get_active_text()
+                service = self._get_active_service()
+                self.forgive_user(account, service)
                 self._reload_account_list()
                 self.cmb_account.get_children()[0].set_text('')
 
@@ -765,7 +646,7 @@ class ConnectingWindow(Login):
     widget that represents the GUI interface showed when connecting
     '''
     def __init__(self, callback, avatar_path, config):
-        LoginBase.__init__(self, callback)
+        LoginBaseUI.__init__(self, callback)
 
         self.callback = callback
         self.avatar.set_from_file(avatar_path)
