@@ -18,14 +18,11 @@
 
 import gtk
 
-import e3
 import gui
 import extension
 
 import logging
 
-from gui import Desktop
-
 log = logging.getLogger('gtkui.MainWindow')
 
 class MainWindow(gtk.VBox, gui.MainWindowBase):
@@ -79,9 +76,9 @@ class MainWindow(gtk.VBox, gui.MainWindowBase):
         self.pack_start(self.below_menu, False)
         self.pack_start(self.panel, False)
         self.pack_start(self.below_panel, False)
+        self.pack_start(self.entry, False)
         self.pack_start(scroll, True, True)
         self.pack_start(self.below_userlist, False)
-        self.pack_start(self.entry, False)
 
         self.contact_list.contact_selected.subscribe(self._on_contact_selected)
         self.contact_list.group_selected.subscribe(self._on_group_selected)
@@ -106,13 +103,19 @@ class MainWindow(gtk.VBox, gui.MainWindowBase):
         self.on_mail_click()
 
     def _on_social_request(self, conn_url):
-        Desktop.open(conn_url)
+        def set_token(token_url):
+            if token_url.find("#access_token=") == -1:
+                return
 
-        def set_token(token):
+            pattern_start_token = "#access_token="
+            pattern_end_token = "&expires_in"
+            start_token = token_url.find(pattern_start_token) + len(pattern_start_token)
+            end_token = token_url.find(pattern_end_token)
+            token = token_url[start_token:end_token]
             self.session.config.facebook_token = token
-        dialog = extension.get_default('dialog')
-        fb_token_dialog = dialog.facebook_token_window("", set_token)
 
+        dialog = extension.get_default('dialog')
+        dialog.web_window(_("Connect Emesene and Facebook"), conn_url ,set_token)
 
     def _on_show_userpanel_changed(self, value):
         '''callback called when config.b_show_userpanel changes'''
@@ -158,7 +161,7 @@ class MainWindow(gtk.VBox, gui.MainWindowBase):
         self.remove(self.below_userlist)
         self.below_userlist = extension.get_and_instantiate('below userlist', self)
         self.pack_start(self.below_userlist, False)
-        pos = len(self.get_children()) - 2
+        pos = len(self.get_children()) - 1
         self.reorder_child(self.below_userlist, pos)
         self.below_userlist.show()
 
@@ -180,6 +183,7 @@ class MainWindow(gtk.VBox, gui.MainWindowBase):
         self._replace_below_userlist()
         self._replace_below_menu()
         self._replace_below_panel()
+        self.panel.replace_userpanel_extension(self)
 
     def _on_entry_changed(self, entry, *args):
         '''called when the text on entry changes'''
@@ -241,6 +245,18 @@ class MainWindow(gtk.VBox, gui.MainWindowBase):
                 self.entry.grab_focus()
             else:
                 self.entry.hide()
+        elif not self.panel.nick.has_focus() and \
+             not self.panel.message.has_focus():
+            if event.string != "" and event.keyval != gtk.keysyms.Return and \
+               event.keyval != gtk.keysyms.KP_Enter:
+                if not self.panel.search.get_active():
+                    self.panel.search.set_active(True)
+                    self.entry.show()
+                    self.entry.grab_focus()
+            elif event.keyval == gtk.keysyms.BackSpace and \
+                 self.entry.get_text_length() == 1:
+                self.panel.search.set_active(False)
+                self.entry.hide()
 
     def on_disconnect(self, close=None):
         '''callback called when the disconnect option is selected'''
@@ -275,4 +291,3 @@ class MainWindow(gtk.VBox, gui.MainWindowBase):
             self.contact_list.is_searching = False
             self.contact_list.show_empty_groups = self.session.config.b_show_empty_groups
             self.contact_list.un_expand_groups()
-
