@@ -20,7 +20,6 @@ import gtk
 
 import e3.common
 import gui
-import utils
 import subprocess
 import sys
 import extension
@@ -32,7 +31,6 @@ import PluginWindow
 import ExtensionList
 
 import logging
-import os
 
 log = logging.getLogger('gtkui.Preferences')
 
@@ -52,6 +50,7 @@ LIST = [
     {'stock_id' : gtk.STOCK_SELECT_COLOR,'text' : _('Theme')},
     {'stock_id' : gtk.STOCK_EXECUTE,'text' : _('Extensions')},
     {'stock_id' : gtk.STOCK_DISCONNECT,'text' : _('Plugins')},
+    {'stock_id' : gtk.STOCK_REFRESH,'text' : _('Updates')},
 ]
 
 class Preferences(gtk.Window):
@@ -115,6 +114,7 @@ class Preferences(gtk.Window):
         self.extension = Extension(session)
         self.plugins = PluginWindow.PluginMainVBox(
             session, config_dir.join('plugins'))
+        self.updates = Update(session)
 
         self.buttons = gtk.HButtonBox()
         self.buttons.set_border_width(2)
@@ -137,6 +137,7 @@ class Preferences(gtk.Window):
         self.theme_page = self.theme
         self.extensions_page = self.extension
         self.plugins_page = self.plugins
+        self.updates_page = self.updates
 
         self.__init_list()
 
@@ -181,6 +182,7 @@ class Preferences(gtk.Window):
         self.page_dict.append(self.theme_page)
         self.page_dict.append(self.extensions_page)
         self.page_dict.append(self.plugins_page)
+        self.page_dict.append(self.updates_page)
 
         for i in LIST:
             # we should use always the same icon size,
@@ -509,7 +511,6 @@ class BaseTable(gtk.Table):
     def on_synch_emesene1(self, button):
         """called when the Synch test button is clicked"""
         syn = extension.get_default('synch tool')
-        user = self.session.account.account
         current_service = self.session.config.service
         syn = syn(self.session, current_service)
         syn.show(True)
@@ -550,7 +551,7 @@ class MainWindow(BaseTable):
                     subprocess.call('defaults write /Applications/emesene.app/Contents/Info LSUIElement -bool true', shell=True)
 
             self.append_markup('<b>'+_('OS X Integration:')+'</b>')
-            self.session.config.get_or_set('b_show_dock_icon', True)    
+            self.session.config.get_or_set('b_show_dock_icon', False)    
             button = self.append_check(_('Show dock icon (requires restart of emesene)'),
                          'session.config.b_show_dock_icon')
             button.connect("toggled", do_hideshow)
@@ -865,6 +866,32 @@ class Theme(BaseTable):
         self.fill_combo(self.adium_variant_combo,
             gui.theme.conv_theme.get_theme_variants, 'session.config.adium_theme_variant')
 
+class Update(BaseTable):
+    """the panel to display/modify the config related to the theme
+    """
+
+    def __init__(self, session):
+        """constructor
+        """
+        BaseTable.__init__(self, 1, 1)
+        self.set_border_width(5)
+        self.session = session
+
+        self.tabs = ExtensionList.UpdateList(session)
+
+        self.tabs.append_theme(_('Image theme'), 'images', gui.theme.image_themes,
+            'session.config.image_theme')
+        self.tabs.append_theme(_('Sound theme'), 'sounds', gui.theme.sound_themes,
+            'session.config.sound_theme')
+        self.tabs.append_theme(_('Emote theme'), 'emotes', gui.theme.emote_themes,
+            'session.config.emote_theme')
+        self.tabs.append_theme(_('Adium theme'), 'conversations', gui.theme.conv_themes,
+            'session.config.adium_theme')
+        self.add(self.tabs)
+
+    def on_update(self):
+        self.tabs.on_update()
+
 class Extension(BaseTable):
     """the panel to display/modify the config related to the extensions
     """
@@ -1344,4 +1371,4 @@ class PrivacySettings(gtk.VBox):
             if action == stock.YES:
                 self.session.remove_contact(model.get_value(iter, 0))
         except TypeError:
-            pass
\ No newline at end of file
+            pass
