@@ -1,25 +1,37 @@
 # -*- coding: utf-8 -*-
 
+#    This file is part of emesene.
+#
+#    emesene is free software; you can redistribute it and/or modify
+#    it under the terms of the GNU General Public License as published by
+#    the Free Software Foundation; either version 3 of the License, or
+#    (at your option) any later version.
+#
+#    emesene is distributed in the hope that it will be useful,
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#    GNU General Public License for more details.
+#
+#    You should have received a copy of the GNU General Public License
+#    along with emesene; if not, write to the Free Software
+#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 ''' This module contains classes to represent the login page '''
 
 import logging
 
-from PyQt4          import QtGui
-from PyQt4          import QtCore
-from PyQt4.QtCore   import Qt
+from PyQt4 import QtGui
+from PyQt4 import QtCore
+from PyQt4.QtCore import Qt
 
 from gui.qt4ui.Utils import tr
 
-import base64
-
 import extension
 import e3
 import gui
 
-
 log = logging.getLogger('qt4ui.LoginPage')
 
-class LoginPage(QtGui.QWidget):
+class LoginPage(QtGui.QWidget, gui.LoginBase):
     ''' The Login Page '''
     # pylint: disable=W0612
     NAME = 'LoginPage'
@@ -27,114 +39,112 @@ class LoginPage(QtGui.QWidget):
     AUTHOR = 'Gabriele "Whisky" Visconti'
     WEBSITE = ''
     # pylint: enable=W0612
-    
+
     def __init__(self, callback, on_preferences_changed, config=None,
                  config_dir=None, config_path=None, proxy=None, use_http=None,
                  session_id=None, cancel_clicked=False, no_autologin=False,
                  parent=None):
         '''Constructor'''
         # pylint: disable=R0913
-        
+
         # NOTE: a 'session' is an object like e3.jabber.Session.Session, so, representing a protocol
         # a 'service' is a service using a given protocol.
-         
+
         # instance variables:
         QtGui.QWidget.__init__(self, parent)
-
-        self._on_preferences_changed = on_preferences_changed
-        self._config = config
-        self._config_dir = config_dir
-        self._config_path = config_path
-        self._session_id = session_id       # DON'T USE
-        self._proxy = proxy or e3.Proxy()
-        self._use_http = use_http           # DON'T USE
-        self._login_callback = callback
+        gui.LoginBase.__init__(self, callback, on_preferences_changed,
+                                config, config_dir, config_path,
+                                proxy, use_http, session_id, no_autologin)
 
         # a widget dic to avoid proliferation of instance variables:
         self._widget_d = {}
         self._account_list = []
-        self._service2data = {}
-        self._service2id   = {}
-        self._host = None
-        self._port = None
         self.autologin_started = False
 
         # setup code:
-        self._setup_config()
         self._setup_accounts()
         self._setup_ui()
         self._on_chosen_account_changed(0)
-        
+
         # selects the default account if any:
         account_combo = self._widget_d['account_combo']
-        if self._config.last_logged_account != '':
+
+        if self.config.last_logged_account != '':
             account_combo.setCurrentIndex(account_combo.findData(0))
             self._on_chosen_account_changed(0)
-            if not cancel_clicked and not no_autologin and \
+            if not cancel_clicked and not self.no_autologin and \
                     config.d_remembers[config.last_logged_account] == 3:
                 self.autologin_started = True
                 self._on_start_login()
-            
+
         # TODO: this way, if there are remembered accounts, but no default 
         #account, no display pic is shown....
-        
 
-    def _setup_config(self):
-        '''Adds missing options to config file'''
-        log.info('*** _setup_config')
-        default_session = extension.get_default('session')
-        service = default_session.SERVICES.keys()[0]
-        self._host = default_session.SERVICES[service]['host']
-        self._port = default_session.SERVICES[service]['port']
-        self._config.get_or_set('last_logged_account', '')
-        self._config.get_or_set('d_remembers', {})
-        self._config.get_or_set('d_user_service', {})
-        self._config.get_or_set('d_status', {})
-        self._config.get_or_set('service', service)
-        # obtaining host and port info for each service
-        for ext_id, ext_class in extension.get_extensions('session').\
-                                 iteritems():
-            for service_name, service_data in ext_class.SERVICES.iteritems():
-                self._service2data[service_name] = service_data
-                self._service2id[service_name] = ext_id
-        
-        
     def _setup_ui(self):
         '''Instantiates the widgets, and sets the layout'''
         widget_d = self._widget_d
-        avatar_cls          = extension.get_default('avatar')
-        status_combo_cls    = extension.get_default('status combo') 
+        avatar_cls = extension.get_default('avatar')
+        status_combo_cls = extension.get_default('status combo')
         widget_d['display_pic'] = avatar_cls(default_pic=gui.theme.image_theme.logo,
-                                                clickable=False)
+                                            clickable=False)
+
+        account_box = QtGui.QHBoxLayout()
+        widget_d['account_box'] = account_box
         widget_d['account_combo'] = QtGui.QComboBox()
+        account_img = QtGui.QLabel()
+        account_img.setPixmap(QtGui.QPixmap(gui.theme.image_theme.user))
+        widget_d['account_img'] = account_img
+        widget_d['forgive_me_btn']  = QtGui.QToolButton()
+        widget_d['forgive_me_btn'].setAutoRaise(True)
+        widget_d['forgive_me_btn'].setIcon(
+                                    QtGui.QIcon.fromTheme('edit-delete'))
+        account_box.addWidget(widget_d['account_img'])
+        account_box.addWidget(widget_d['account_combo'])
+        account_box.addWidget(widget_d['forgive_me_btn'])
+
+
+        password_box = QtGui.QHBoxLayout()
+        widget_d['password_box'] = password_box
         widget_d['password_edit'] = QtGui.QLineEdit()
+        password_img = QtGui.QLabel()
+        password_img.setPixmap(QtGui.QPixmap(gui.theme.image_theme.password))
+        widget_d['password_img'] = password_img
+        password_box.addWidget(widget_d['password_img'])
+        password_box.addWidget(widget_d['password_edit'])
+        password_box.addSpacing(32)
+
+        status_box = QtGui.QHBoxLayout()
+        widget_d['status_box'] = status_box
         widget_d['status_combo']  = status_combo_cls()
+        widget_d['advanced_btn']  = QtGui.QToolButton()
+        status_box.addSpacing(36)
+        status_box.addWidget(widget_d['status_combo'])
+        status_box.addWidget(widget_d['advanced_btn'])
+
+        layv = QtGui.QVBoxLayout()
         widget_d['save_account_chk'] =    \
                 QtGui.QCheckBox(tr('Remember me'))
         widget_d['save_password_chk'] =   \
                 QtGui.QCheckBox(tr('Remember password'))
         widget_d['auto_login_chk'] =  \
                 QtGui.QCheckBox(tr('Auto-login'))
-        widget_d['advanced_btn']  = QtGui.QToolButton() 
         widget_d['login_btn'] = QtGui.QPushButton(tr('Connect'))
 
         lay = QtGui.QVBoxLayout()
         lay.addSpacing(40)
         lay.addWidget(widget_d['display_pic'], 0, Qt.AlignCenter)
         lay.addSpacing(40)
-        lay.addWidget(widget_d['account_combo'])
-        lay.addWidget(widget_d['password_edit'])
-        lay.addWidget(widget_d['status_combo'])
+        lay.addLayout(widget_d['account_box'])
+        lay.addLayout(widget_d['password_box'])
+        lay.addLayout(widget_d['status_box'])
         lay.addSpacing(20)
         lay.addWidget(widget_d['save_account_chk'])
         lay.addWidget(widget_d['save_password_chk'])
         lay.addWidget(widget_d['auto_login_chk'])
-        lay.addWidget(widget_d['advanced_btn'], 0, Qt.AlignRight)
         lay.addSpacing(35)
         lay.addStretch()
         lay.addWidget(widget_d['login_btn'], 0, Qt.AlignCenter)
         lay.addSpacing(45)
-        
 
         hor_lay = QtGui.QHBoxLayout()
         hor_lay.addStretch()
@@ -143,12 +153,12 @@ class LoginPage(QtGui.QWidget):
         hor_lay.addSpacing(40)
         hor_lay.addStretch()
         self.setLayout(hor_lay)
-        
+
         # insert accounts in the combo box:
         account_combo = widget_d['account_combo']
         for account in self._account_list:
             account_combo.addItem(account.email,
-                                  self._account_list.index(account) )
+                                  self._account_list.index(account))
 
         widget_d['account_combo'].currentIndexChanged.connect(
                                     self._on_chosen_account_changed)
@@ -159,14 +169,16 @@ class LoginPage(QtGui.QWidget):
         widget_d['save_account_chk'].stateChanged.connect(
                                     self._on_checkbox_state_refresh)
         widget_d['save_password_chk'].stateChanged.connect(
-                                    self._on_checkbox_state_refresh) 
+                                    self._on_checkbox_state_refresh)
         widget_d['auto_login_chk'].stateChanged.connect(
                                     self._on_checkbox_state_refresh)
         widget_d['advanced_btn'].clicked.connect(
                                     self._on_connection_preferences_clicked)
+        widget_d['forgive_me_btn'].clicked.connect(
+                                    self._on_forgive_me_clicked)
         widget_d['login_btn'].clicked.connect(
                                     self._on_start_login)
-                                        
+
         self.installEventFilter(self)
 
         account_combo = widget_d['account_combo']
@@ -183,9 +195,6 @@ class LoginPage(QtGui.QWidget):
         login_btn.setAutoDefault(True)
         login_btn.setEnabled(False)
         login_btn.setMinimumWidth(110)
-                                        
-
-
 
     def _setup_accounts(self):
         '''Builds up the account list'''
@@ -193,49 +202,36 @@ class LoginPage(QtGui.QWidget):
             '''Convenience class to store account's settings'''
             def __init__(self, service, email, password, status, remember_lvl):
                 '''Constructor'''
-                self.service, self.status             = service, status
-                self.email, self.password             = email, password
+                self.service, self.status = service, status
+                self.email, self.password = email, password
                 self.save_account, self.save_password = False, False
-                self.auto_login                       = False
+                self.auto_login = False
                 if remember_lvl >= 1:
                     self.save_account   = True
                 if remember_lvl >= 2:
                     self.save_password  = True
                 if remember_lvl >= 3:
                     self.auto_login     = True
-        
-        service_d         = self._config.d_user_service
-        remember_lvl_d    = self._config.d_remembers
-        emails            = remember_lvl_d.keys()
-        status_d          = self._config.d_status
-        password_d        = self._config.d_accounts
-        default_acc_email = self._config.last_logged_account
+
+        emails = self.remembers.keys()
+        default_acc_email = self.config.last_logged_account
 
         if default_acc_email in emails:
             index = emails.index(default_acc_email)
             # put the default account's email in the first position
             emails[0], emails[index] = emails[index], emails[0]
-            
+
         for email in emails:
-            try:
-                service = service_d[email]
-            except KeyError:
-                continue
-            remember_lvl = remember_lvl_d[email]
-            if remember_lvl >= 1: # we have at least a status
-                status = status_d[email]
-            else:
-                status = e3.status.ONLINE
-            if remember_lvl >= 2: # we have also a password
-                password = base64.b64decode(password_d[email])
-            else:
-                password = ''
+            acc = email.rpartition('|')[0]
+            service = self.config.d_user_service.get(acc, 'msn')
+            remember_lvl = self.remembers[email]
+            status = self.config.d_status.get(email, e3.status.ONLINE)
+            password = self.decode_password(email)
 
-            account = Account(service, email, password, status, remember_lvl)
+            account = Account(service, acc, password, status, remember_lvl)
             self._account_list.append(account)
 
 
-
     def _on_account_combo_text_changed(self, new_text): #new text is a QString
         ''' Slot executed when the text in the account combo changes '''
         log.info('*** _on_account_combo_text_changed')
@@ -257,13 +253,11 @@ class LoginPage(QtGui.QWidget):
         index_in_account_list = account_combo.itemData(acc_index).toPyObject()
         # If we don't have any account at all, this slots gets called but 
         # index_in_account_list is None.
-        if not index_in_account_list is None: 
+        if not index_in_account_list is None:
             account = self._account_list[index_in_account_list]
-        
             self.clear_login_form()
             # display_pic
-            path = self._config_dir.join(self._host, 
-                                         account.email, 'avatars', 'last')
+            path = self.current_avatar_path(account.email)
             widget_d['display_pic'].set_display_pic_from_file(path)
             # password:
             if account.password:
@@ -276,9 +270,8 @@ class LoginPage(QtGui.QWidget):
             widget_d['save_account_chk'] .setChecked(account.save_account)
             widget_d['save_password_chk'].setChecked(account.save_password)
             widget_d['auto_login_chk']   .setChecked(account.auto_login)
-            # host and port:
-            self._host = self._service2data[account.service]['host'] 
-            self._port = self._service2data[account.service]['port']
+
+            self.update_service(account.service)
         self._on_checkbox_state_refresh()
         
     def _on_connection_preferences_clicked(self):
@@ -289,127 +282,69 @@ class LoginPage(QtGui.QWidget):
                                server_host, server_port):
             '''called when the user press accept on the preferences dialog'''
             
-            self._proxy = e3.Proxy(use_proxy, proxy_host,
+            self.proxy = e3.Proxy(use_proxy, proxy_host,
                                    proxy_port, use_auth, user, passwd)
-            self._host = server_host
-            self._port = server_port
+            self.server_host = server_host
+            self.server_port = server_port
             account_email = str(self._widget_d['account_combo'].currentText())
             if account_email != '':
-                self._config.d_user_service[account_email] = service
+                self.config.d_user_service[account_email] = service
                 # to trigger eventual update of dp:
             self._on_account_combo_text_changed(account_email)
-    
-            # TODO: investigate on what does the following do:
-            self._on_preferences_changed(use_http, self._proxy, session_id,
+            self.on_preferences_changed(use_http, self.proxy, session_id,
                     service)
             
 
-        service = self._config.service
+        service = self.config.service
         account = str(self._widget_d['account_combo'].currentText())
-        if account in self._config.d_user_service.keys():
-            service = self._config.d_user_service[account]
-        extension.get_default('dialog').login_preferences(service, self._host,
-                                        self._port, new_preferences_cb, 
-                                        self._config.b_use_http, self._proxy)
+        if account in self.config.d_user_service.keys():
+            service = self.config.d_user_service[account]
+        extension.get_default('dialog').login_preferences(service, self.server_host,
+                                        self.server_port, new_preferences_cb, 
+                                        self.config.b_use_http, self.proxy)
 
+    def _on_forgive_me_clicked(self):
+        ''''''
+        def _yes_no_cb(response):
+            '''callback from the confirmation dialog'''
+            if (response == 36): #Accepted
+                account = str(widget_dic['account_combo'].currentText())
+                service = self.config.d_user_service.get(account, self.config.service)
+                self.forgive_user(account, service)
+                #FIXME: remove fron account_list and combo
+                widget_dic['account_combo'].setCurrentIndex(0)
+
+        widget_dic = self._widget_d
+        extension.get_default('dialog').yes_no(
+                _('Are you sure you want to delete the account %s ?') % \
+                str(widget_dic['account_combo'].currentText()), _yes_no_cb)
 
     def _on_start_login(self):
         ''' Slot executed when the user clicks the login button'''
         widget_dic = self._widget_d
-        user            =  str(widget_dic['account_combo'].currentText())
-        password        =  str(widget_dic['password_edit'].text())
-        status          =      widget_dic['status_combo'].status()
-        save_account    =      widget_dic['save_account_chk'].isChecked()
-        save_password   =      widget_dic['save_password_chk'].isChecked()
-        auto_login      =      widget_dic['auto_login_chk'].isChecked()
+        user = str(widget_dic['account_combo'].currentText())
+        password = str(widget_dic['password_edit'].text())
+        status = widget_dic['status_combo'].status()
+        save_account = widget_dic['save_account_chk'].isChecked()
+        save_password = widget_dic['save_password_chk'].isChecked()
+        auto_login = widget_dic['auto_login_chk'].isChecked()
         
-        if user in self._config.d_user_service.keys():
-            service_name = self._config.d_user_service[user]
-            session_id = self._service2id[service_name]
+        if user in self.config.d_user_service.keys():
+            service_name = self.config.d_user_service[user]
+            self.session_id = self.service2id[service_name][0]
         else:
-            service_name = self._config.service
-            session_id = self._config.session
-        self._config.d_user_service[user] = service_name
+            service_name = self.config.service
+            self.session_id = self.config.session
+        self.config.d_user_service[user] = service_name
         
+        e3_account = e3.Account(user, password, status, self.server_host)
 
-        e3_account = e3.Account(user, password, status, self._host)
-        #is this the email?
-        email = e3_account.account
-
-
-        # saves the account's config:
-        # the "remember field behaves like this:
-        # - 0: save nothing                 - 1: save account
-        # - 2: save account and password    - 3: save all and autologin
-        
-        
-        # TODO: when there's no config file, we have already a d_remembers and 
-        # a d_accounts, but no d_status and last_logged_account. This seems to
-        # be inconsistent. Is this a bug?
-        d_remembers = self._config.d_remembers
-        d_accounts = self._config.d_accounts
-        d_status = self._config.d_status
-        if not d_status:
-            self._config.get_or_set('d_status', {})
-            d_status = self._config.d_status
-        if not self._config.last_logged_account:
-            self._config.get_or_set('last_logged_account', '')
-            
-        
-        
-        if save_account:
-            d_remembers[email] = 1
-            d_status[email] = status
-            self._config.last_logged_account = email
-            if save_password:
-                d_remembers[email] = 2
-                d_accounts[email] = base64.b64encode(e3_account.password)
-                if auto_login:
-                    d_remembers[email] = 3
-            else:
-                if  email in d_accounts:
-                    del d_accounts[email]
-        else:
-            if email in d_remembers:
-                del d_remembers[email]
-            if email in d_status:
-                del d_status[email]
-            if email in d_accounts:
-                del d_accounts[email]
-         
-         # alternative form: 
-#        if auto_login:
-#            self._config.last_logged_account = email
-#            d_remembers[email] = 3
-#            d_status[email] = status
-#            d_accounts[email] = base64.b64encode(e3_account.password)
-#        elif save_password:
-#            d_remembers[email] = 2
-#            self._config.last_logged_account = email
-#            d_status[email] = status
-#            d_accounts[email] = base64.b64encode(e3_account.password)
-#        elif save_account:
-#            self._config.last_logged_account = email
-#            d_remembers[email] = 1
-#            d_status[email] = status
-#            if  email in d_accounts:
-#                del d_accounts[email]
-#        else:
-#            if email in d_remembers:
-#                del d_remembers[email]
-#            if email in d_status:
-#                del d_status[email]
-#            if  email in d_accounts:
-#                del d_accounts[email]
-            
-                
-        self._config.save(self._config_path)
+        self.config_account(e3_account, service_name, save_account, save_password,
+                            auto_login)
             
         # Invoke the  login callback
-        self._login_callback(e3_account, session_id, self._proxy,
-                             self._config.b_use_http, self._host, self._port)
-
-
+        self.callback(e3_account, self.session_id, self.proxy,
+                             self.use_http, self.server_host, self.server_port)
 
     def clear_login_form(self, clear_pic=False):
         ''' Resets the login form '''
@@ -455,8 +390,6 @@ class LoginPage(QtGui.QWidget):
         else:
             login_btn.setEnabled(False)
 
-
-
     # -------------------- QT_OVERRIDE
 
     def eventFilter(self, obj, event):
@@ -470,5 +403,3 @@ class LoginPage(QtGui.QWidget):
             return True
         else:
             return False
-            
-        
